use strict;

use Test::More;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( GetTestSite RunOnStore );
use DE_EPAGES::Object::API::Factory qw( ExistsObjectByPath LoadObjectByPath );

my $ShopPath = $ENV{'SHOP_PATH'} ? $ENV{'SHOP_PATH'} : '/Shops/DemoShop';

sub Main {

    SKIP: {
        skip "No $ShopPath exists" unless ExistsObjectByPath($ShopPath);

        my $DemoShop = LoadObjectByPath($ShopPath);
        my $hClosedInfo = $DemoShop->get( [qw(IsClosed ClosedByMerchant ClosedByProvider)] );

        fail('DemoShop closed')
            if($hClosedInfo->{IsClosed} || $hClosedInfo->{ClosedByMerchant} || $hClosedInfo->{ClosedByProvider});

        my $DemoShopURL = $DemoShop->get('WebUrlSSL');
        my $Command = "$ENV{PERL} $ENV{EPAGES_CARTRIDGES}/".
            "DE_EPAGES/Presentation/Scripts/shophtmlvalidator.pl -start $DemoShopURL";
        print "-> $Command\n";
        exec $Command;
    }

    done_testing();
}

RunScript( Sub => sub {
    RunOnStore( Store => GetTestSite(), Sub => \&Main );
});
