#========================================================================================
# package      DE_EPAGES::ShopMigration::API::Cartridge
# base         DE_EPAGES::Shop::API::ShopInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::ShopMigration::API::Cartridge;
use base DE_EPAGES::Shop::API::ShopInstaller;

use strict;
use DE_EPAGES::Object::API::Factory qw(LoadRootObject);
use DE_EPAGES::ShopMigration::API::Constants qw(PREPSHOPS_FOLDER_ALIAS);
#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::ShopMigration::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::ShopMigration.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges</li>
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/ShopMigration',
        'Version'            => '7.53.0',
        'Patches'            => [],
        'HasDbSchema'        => 0,
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    LoadRootObject()->folder(PREPSHOPS_FOLDER_ALIAS, { 'Position' => '110' });
    $self->finishInstall;
    return;
}

#========================================================================================
# function     uninstall
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    $self->finishUninstall;
    return;
}

1;
