#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::CategoriesExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import categories objects.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::CategoriesExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportCategoriesJSON
    ImportCategoriesJSON
);

#========================================================================================
# function     ExportCategoriesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportCategoriesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports mailtype data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportCategoriesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CategoriesHandler = __PACKAGE__->new($Shop);
    return $CategoriesHandler->exportJSONData($DirName, $CategoriesHandler->getExportItems());
}

#========================================================================================
# function     ImportCategoriesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportCategoriesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports mailtype data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportCategoriesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CategoriesHandler = __PACKAGE__->new($Shop);
    return $CategoriesHandler->importJSONData($DirName);
}

#========================================================================================
# function     getExportItems
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->getExportItems()
#----------------------------------------------------------------------------------------
# description  Creates a list of exportable items (list of objectids)
#----------------------------------------------------------------------------------------
# return       $aItems | list of objectids | ref.array
#========================================================================================
sub getExportItems {
    my $self = shift;

    my $Shop = $self->shop();
    my @Items = ($Shop->get('Categories')->id);
    push @Items, map {$_->id} @{$Shop->get('Categories')->get('RecursiveSubCategories')};
    return \@Items;
}

#========================================================================================
# function     importDriver
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Driver->importDriver();
#----------------------------------------------------------------------------------------
# description  Return driver package.
#----------------------------------------------------------------------------------------
# return       $DriverPackage  | package to driver | string
#========================================================================================
sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CategoriesImportHandler';
}

#========================================================================================
# function     exportDriver
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Driver->exportDriver();
#----------------------------------------------------------------------------------------
# description  Return driver package.
#----------------------------------------------------------------------------------------
# return       $DriverPackage  | package to driver | string
#========================================================================================
sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CategoriesExportDriver';
}

1;
