#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::CategoryProductMapsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import category product maps.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::CategoryProductMapsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportCategoryProductMapsJSON
    ImportCategoryProductMapsJSON
);

use DE_EPAGES::ShopMigration::API::CategoryProductMapsCommon qw(GetCategoryProductMapIDs);

#========================================================================================
# function     ExportCategoryProductMapsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportCategoryProductMapsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports category product maps data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportCategoryProductMapsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CategoryProductMapsHandler = __PACKAGE__->new($Shop);
    return $CategoryProductMapsHandler->exportJSONData($DirName, $CategoryProductMapsHandler->getExportItems());
}

#========================================================================================
# function     ImportCategoryProductMapsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportCategoryProductMapsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports category product maps data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportCategoryProductMapsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CategoryProductMapsHandler = __PACKAGE__->new($Shop);
    return $CategoryProductMapsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    return GetCategoryProductMapIDs($self->shop());
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CategoryProductMapsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CategoryProductMapsExportDriver';
}

1;
