#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::CrossSellingsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import cross selling.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::CrossSellingsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportCrossSellingsJSON
    ImportCrossSellingsJSON
);

use DE_EPAGES::ShopMigration::API::CrossSellingsCommon qw(GetCrossSellingIDs);

#========================================================================================
# function     ExportCrossSellingsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportCrossSellingsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports category product maps data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportCrossSellingsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CrossSellingsHandler = __PACKAGE__->new($Shop);
    return $CrossSellingsHandler->exportJSONData($DirName, $CrossSellingsHandler->getExportItems());
}

#========================================================================================
# function     ImportCrossSellingsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportCrossSellingsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports category product maps data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportCrossSellingsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $CrossSellingsHandler = __PACKAGE__->new($Shop);
    return $CrossSellingsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;
    return GetCrossSellingIDs($self->shop());
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CrossSellingsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::CrossSellingsExportDriver';
}

1;
