#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::LegalPagesExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import legal pages data.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::LegalPagesExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportLegalPagesJSON
    ImportLegalPagesJSON
);
use DE_EPAGES::ShopMigration::API::Constants qw(@LEGELPAGES_ALIASES);

#========================================================================================
# function     ExportLegalPagesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportLegalPagesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports legal pages data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportLegalPagesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $LegalPagesHandler = __PACKAGE__->new($Shop);
    return $LegalPagesHandler->exportJSONData($DirName, $LegalPagesHandler->getExportItems());
}

#========================================================================================
# function     ImportLegalPagesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportLegalPagesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports legal pages data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportLegalPagesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $LegalPagesHandler = __PACKAGE__->new($Shop);
    return $LegalPagesHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;

    my $Shop = $self->shop();
    my @Items;
    my $Folder = $Shop->get('IsMigrationPrepShop') ? $Shop->child('LegalPagesUnity') : $Shop->child('Categories');
    foreach my $Alias (@LEGELPAGES_ALIASES) {
        my $PageID = $Folder->findChild($Alias);
        next unless defined $PageID;
        push @Items, $PageID;
    }
    return \@Items;
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::LegalPagesImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::LegalPagesExportDriver';
}

1;
