#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::MailTypesExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions to export / import mailtype objects.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::MailTypesExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportMailTypesJSON
    ImportMailTypesJSON
);

#========================================================================================
# function     ExportMailTypesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportMailTypesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports mailtype data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportMailTypesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $MailTypesHandler = __PACKAGE__->new($Shop);
    return $MailTypesHandler->exportJSONData($DirName, $MailTypesHandler->getExportItems());
}

#========================================================================================
# function     ImportMailTypesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportMailTypesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports mailtype data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportMailTypesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $MailTypesHandler = __PACKAGE__->new($Shop);
    return $MailTypesHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;

    my $Shop = $self->shop();
    return $Shop->folder('MailTypes')->findChildren;
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::MailTypesImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::MailTypesExportDriver';
}

1;
