#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ProductTypesExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions for export / import of product types
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ProductTypesExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
our @EXPORT_OK = qw(
    ExportProductTypesJSON
    ImportProductTypesJSON
);

#========================================================================================
# function     ExportProductTypesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportProductTypesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports mailtype data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportProductTypesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ProductTypesHandler = __PACKAGE__->new($Shop);
    return $ProductTypesHandler->exportJSONData($DirName, $ProductTypesHandler->getExportItems());
}

#========================================================================================
# function     ImportProductTypesJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportProductTypesJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports mailtype data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportProductTypesJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ProductTypesHandler = __PACKAGE__->new($Shop);
    return $ProductTypesHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;

    my $Shop = $self->shop();
    my @Items;
    push @Items, $Shop->get('ProductClass')->id;
    if ($Shop->existsChild('ProductTypes')) {
        push @Items, map {$_->id} grep {$_->class->alias eq 'ProductType'} @{$Shop->child('ProductTypes')->children};
    }
    return \@Items;
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ProductTypesImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ProductTypesExportDriver';
}

1;
