#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ProductsExportDriver
# state        public
#----------------------------------------------------------------------------------------
# description  exports products for shop / prepshop
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ProductsExportDriver;
use base DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportDriver;

use strict;

use DE_EPAGES::Core::API::IniConfig;
use DE_EPAGES::Object::API::Factory qw(LoadObject ExistsObject);
use DE_EPAGES::ShopMigration::API::ProductsCommon qw(GetProductData ExportProductFiles);
use DE_EPAGES::ShopMigration::API::Constants qw($EXPORT_FILES_AND_FILEATTRIBUTES);

use File::Spec::Functions;

#========================================================================================
# function     defaultBaseFileName
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->defaultBaseFileName;
#----------------------------------------------------------------------------------------
# description  returns the default json filename
#----------------------------------------------------------------------------------------
# return       $FileName | file name | string
#========================================================================================
sub defaultBaseFileName {
    return 'products.json';
}

#========================================================================================
# function     dirNameFiles
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->dirNameFiles;
#----------------------------------------------------------------------------------------
# description  returns the base directory name to be used for file export
#----------------------------------------------------------------------------------------
# return       $DirName | directory name | string
#========================================================================================
sub dirNameFiles {
    my $self = shift;

    my $DirName = $self->isMigrationPrepShop ? 'Prep2Base' : 'Base2Prep';
    return catdir($self->dirName(), 'Files', $DirName);
}

#========================================================================================
# function     exportLine
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->exportLine();
#----------------------------------------------------------------------------------------
# description  exports one data line, get the line element from function topID('Item')
#               and exports the product images and other files to $self->dirNameFiles()
#               while keeping track of the original FileAliases in $self->mapAlias2FileAlias
#========================================================================================
sub exportLine {
    my $self = shift;

    my $ObjectID = $self->topID('Item');
    if (ExistsObject($ObjectID)) {
        my $Product = LoadObject($ObjectID);
        my $hValues = GetProductData($self->shop, $Product);
        $self->writeLine($hValues) if (keys %$hValues);
        my $hOptions = { CopyMediumImages => $self->isMigrationPrepShop };
        ExportProductFiles($Product, $self->dirNameFiles(), $hOptions) if $EXPORT_FILES_AND_FILEATTRIBUTES;
    }
    return;
}

1;
