#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ProductsExportImport;
# state        public
#----------------------------------------------------------------------------------------
# description  Some helper functions for export / import of products
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ProductsExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
use DE_EPAGES::ShopMigration::API::ProductsCommon qw(GetProductsIterator);
our @EXPORT_OK = qw(
    ExportProductsJSON
    ImportProductsJSON
);

#========================================================================================
# function     ExportProductsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportProductsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports legal pages data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportProductsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ProductsHandler = __PACKAGE__->new($Shop);
    return $ProductsHandler->exportJSONData($DirName, $ProductsHandler->getExportItems());
}

#========================================================================================
# function     ImportProductsJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportProductsJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports legal pages data from a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportProductsJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ProductsHandler = __PACKAGE__->new($Shop);
    return $ProductsHandler->importJSONData($DirName);
}

sub getExportItems {
    my $self = shift;

    return GetProductsIterator($self->shop());
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ProductsImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ProductsExportDriver';
}

1;
