#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ProductsImportHandler
# state        public
#----------------------------------------------------------------------------------------
# description  imports products for the shop / prepshop
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ProductsImportHandler;
use base DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectImportHandler;

use strict;
use 5.010; # Needed because we use state vars
use DE_EPAGES::ShopMigration::API::ProductsCommon qw(SetProductData ImportProductFiles);
use File::Spec::Functions;

#========================================================================================
# function     defaultBaseFileName
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->defaultBaseFileName;
#----------------------------------------------------------------------------------------
# description  returns the default json filename
#----------------------------------------------------------------------------------------
# return       $FileName | file name | string
#========================================================================================
sub defaultBaseFileName {
    return 'products.json';
}

#========================================================================================
# function     setShopDataPrepShop
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->setShopDataPrepShop($hFields);
#----------------------------------------------------------------------------------------
# input        $hLineData | Hash with Values | ref hash string
# description  Imports legal pages data from $hFields to the prep shop
#========================================================================================
sub setShopDataPrepShop {
    my $self = shift;
    my ($hLineData) = @_;

    my $OldFilePathPart = $hLineData->{Attributes}{RelativeFilePathPart};
    my $Product = SetProductData($self->shop(), $hLineData);
    ImportProductFiles($Product, $self->dirNameFiles(), $OldFilePathPart, { ScaleImages => 1 });
}

#========================================================================================
# function     setShopDataBaseShop
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->setShopDataBaseShop($hFields);
#----------------------------------------------------------------------------------------
# input        $hLineData | Hash with Values | ref hash string
# description  Imports legal pages data from $hFields to the base shop
#========================================================================================
sub setShopDataBaseShop {
    my $self = shift;
    my ($hLineData) = @_;

    my $OldFilePathPart = $hLineData->{Attributes}{RelativeFilePathPart};
    my $Product = SetProductData($self->shop(), $hLineData);
    ImportProductFiles($Product, $self->dirNameFiles(), $OldFilePathPart, { ScaleImages => 0 });
}

#========================================================================================
# function     dirNameFiles
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->dirNameFiles;
#----------------------------------------------------------------------------------------
# description  returns the base directory name to be used for file export
#----------------------------------------------------------------------------------------
# return       $DirName | directory name | string
#========================================================================================
sub dirNameFiles {
    my $self = shift;

    my $DirName = $self->isMigrationPrepShop ? 'Base2Prep' : 'Prep2Base';
    return catdir($self->dirName(), 'Files', $DirName);
}

1;
