#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ShopDataExportImport
# state        public
#----------------------------------------------------------------------------------------
# description  This module implements the interface for import and export of
#               shop object to JSONLines files.
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ShopDataExportImport;
use base qw(DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportImport Exporter);

use strict;
use DE_EPAGES::Core::API::TestParameter qw(TestObject TestString);
use DE_EPAGES::ShopMigration::API::ShopCommonData qw(GetShopData);
our @EXPORT_OK = qw(
    ExportShopDataJSON
    ImportShopDataJSON
);

#========================================================================================
# function     ExportShopDataJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ExportShopDataJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Exports shop data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Exporter |  exporter | object
#========================================================================================
sub ExportShopDataJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ShopDataHandler = __PACKAGE__->new($Shop);
    return $ShopDataHandler->exportJSONData($DirName, $ShopDataHandler->getExportItems());
}

#========================================================================================
# function     ImportShopDataJSON
# state        public
#----------------------------------------------------------------------------------------
# syntax       ImportShopDataJSON($Shop, $DirName)
#----------------------------------------------------------------------------------------
# description  Imports shop data to a json file
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $DirName | export directory | string
# return       $Importer |  importer | object
#========================================================================================
sub ImportShopDataJSON {
    my ($Shop, $DirName) = @_;
    TestObject('Shop', $Shop);
    TestString('DirName', $DirName);

    my $ShopDataHandler = __PACKAGE__->new($Shop);
    return $ShopDataHandler->importJSONData($DirName);
}

#========================================================================================
# function     getExportItems
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->getExportItems()
#----------------------------------------------------------------------------------------
# description  Creates a list of exportable items (list of objectids)
#----------------------------------------------------------------------------------------
# return       $aItems | list of objectids | ref.array
#========================================================================================
sub getExportItems {
    my $self = shift;

    return [ GetShopData($self->shop()) ];
}

sub importDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ShopDataImportHandler';
}

sub exportDriver {
    my $self = shift;
    return 'DE_EPAGES::ShopMigration::API::JSONLines::ShopDataExportDriver';
}

1;
