#========================================================================================
# package      DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportDriver
# state        public
#----------------------------------------------------------------------------------------
# description  Base class for json lines export drivers based on a shop object
#========================================================================================
package DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportDriver;
use base DE_EPAGES::ShopMigration::API::JSONLines::BaseExportDriver;

use strict;
use DE_EPAGES::Core::API::Error qw(Error);
use File::Spec::Functions;

#ERRORDEFINITION
sub ErrorDefinition {
    return {
        'JSON_SHOP_UNDEFINED' => 'Hash element Shop is mandatory for this function call',
    };
}
#ERRORDEFINITION

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Exporter = DE_EPAGES::ShopMigration::API::JSONLines::ShopObjectExportDriver->new(%Options);
#----------------------------------------------------------------------------------------
# description  create a new json export driver
#----------------------------------------------------------------------------------------
# input        todo options!: $Shop     |  shop object | object
# return       $Exporter |  exporter    | object
#========================================================================================
sub new {
    my $class = shift;
    my (%Options) = @_;

    my ($Shop, $DirName);
    if (exists $Options{Shop}) {
        $Shop = $Options{Shop};
        delete $Options{Shop};
    }
    if (exists $Options{DirName}) {
        $DirName = $Options{DirName};
        delete $Options{DirName};
    }
    $DirName //= '.';
    Error('JSON_SHOP_UNDEFINED') unless defined $Shop;
    my $self = $class->SUPER::new(%Options);
    $self->shop($Shop);
    $self->isMigrationPrepShop($Shop->get('IsMigrationPrepShop'));
    #add shop alias to dirname, add correct prefix
    if ($self->isMigrationPrepShop) {
        $self->dirName(catdir($DirName, $Shop->get('MigrationShop')->alias));
        $self->baseFileName('prep2base_' . $self->defaultBaseFileName());
    }
    else {
        $self->dirName(catdir($DirName, $Shop->alias));
        $self->baseFileName('base2prep_' . $self->defaultBaseFileName());
    }
    return $self;
}

#========================================================================================
# function     shop
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->shop;
# syntax       $self->shop($Shop);
#----------------------------------------------------------------------------------------
# description  returns or sets the shop object for the exporter (used in subclasses)
#----------------------------------------------------------------------------------------
# input        $Shop | new shop | object
# return       $FileName | file name | string
#========================================================================================
sub shop {
    my $self = shift;
    my ($Shop) = @_;
    if (@_ == 1) {
        $self->{Shop} = $Shop;
    }
    return $self->{Shop};
}

#========================================================================================
# function     isMigrationPrepShop
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->isMigrationPrepShop;
# syntax       $self->isMigrationPrepShop(0);
#----------------------------------------------------------------------------------------
# description  returns or sets the isMigrationPrepShop field
#----------------------------------------------------------------------------------------
# input        $Value | isMigrationPrepShop | boolean
# return       $FileName | file name | string
#========================================================================================
sub isMigrationPrepShop {
    my $self = shift;
    my ($Value) = @_;
    if (@_ == 1) {
        $self->{IsMigrationPrepShop} = $Value;
    }
    return $self->{IsMigrationPrepShop};
}

1;
