#========================================================================================
# package      DE_EPAGES::ShopMigration::API::PrepShopLoginToken
# state        public
#----------------------------------------------------------------------------------------
# description  Provides helper functions for handling prep shop login tokens.
#========================================================================================
package DE_EPAGES::ShopMigration::API::PrepShopLoginToken;
use base qw(Exporter);

use strict;

use DE_EPAGES::Core::API::PerlTools qw(AddDuration GetLocalTimeZone GetCurrentDateTime);
use DE_EPAGES::Object::API::Factory qw(LoadRootObject);

our @EXPORT_OK = qw(
    IsValidToken
);

#========================================================================================
# function     IsValidToken
# state        public
#----------------------------------------------------------------------------------------
# syntax       IsValidToken($LoginToken, $LoginTokenFolder);
#----------------------------------------------------------------------------------------
# description  checks if a login token exists, is valid and
#               compares CreationDate + PrepShopTokenLifetime is higher than current time
#----------------------------------------------------------------------------------------
# input        $LoginToken | the token to check | string
# input        $LoginTokenFolder | user folder for login tokens  | object
# return       1 if token is valid, 0 otherwise
#========================================================================================
sub IsValidToken {
    my ($LoginToken, $LoginTokenFolder) = @_;

    return 0 unless $LoginTokenFolder->existsChild($LoginToken);

    my $LoginTokenObject = $LoginTokenFolder->child($LoginToken);
    my $LoginTokenLifetime = LoadRootObject()->get('PrepShopTokenLifetime');

    my $LifetimeLimit = AddDuration(
        $LoginTokenObject->get('CreationDate')->set_time_zone(GetLocalTimeZone()), 'seconds', $LoginTokenLifetime
    );

    if ($LoginTokenObject->get('IsValid') &&
        DateTime->compare(GetCurrentDateTime()->set_time_zone('UTC'), $LifetimeLimit->set_time_zone('UTC')) == -1) {
        return 1;
    } else {
        return 0;
    }
}

1;