# ShopMigration How-To 

## Prepare a base shop
* Setup a base shop which can be migrated to a now shop (Only one Currency) 
```
{
ALIAS=milestones
PREPSHOPALIAS=prepshop${ALIAS,,}
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/deleteObject.pl -storename Site -path /Providers/Distributor/ShopRefs/$ALIAS
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/deleteObject.pl -storename Store -path /PrepShops/$PREPSHOPALIAS
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/deleteObject.pl -storename Store -path /Shops/$ALIAS
}

{
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopConfiguration/Scripts/createShop.pl -wsuser /Providers/Distributor/Users/admin -passwd admin -alias $ALIAS -scriptname $ALIAS -shoptype Demo -storename Store
cat > $EPAGES_PATCHES/ShopWizard.conf <<EOF
[SHOP]
Languages=en

[ADDRESS]
EMail=blackhole@epages.com
FirstName=Max
LastName=Mustermann
Company=Milestones GmbH
City=London
Zipcode=07743
CountryID=826
Street=Leutragraben 1
Phone=12345/54321
Fax=12345/54322
EOF
$PERL $EPAGES_CARTRIDGES/DE_EPAGES/ShopWizard/Scripts/runWizard.pl -storename Store -config $EPAGES_PATCHES/ShopWizard.conf -shop $ALIAS
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/set.pl -storename Store -path /Shops/$ALIAS LastMerchantLogin=2020-07-29T18:17:28
}
```

* adapt the shop (remove extra inactive EUR currency in MBO please)
```
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/set.pl -storename Store -path "/Shops/$ALIAS" CurrencyID=GBP

AdminURL=$($PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/get.pl -storename Store -path /Shops/$ALIAS WebServerScriptAdminUrlSSL| grep WebServerScriptAdminUrlSSL | cut -d"=" -f2)
echo $AdminURL
```

* update shopmigration.conf if it was changed manually after installation
```
{
cd /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration
diff Data/SharedConfig/shopmigration.conf /srv/epages/eproot/Shared/Config/shopmigration.conf
\cp -fvp  Data/SharedConfig/shopmigration.conf /srv/epages/eproot/Shared/Config/shopmigration.conf
}
```

* remove restriction of hasLastOrderWithinDays unless you have created an order in your shop
* remove PriceLists and set proper ProductLowOnStockAction
```
{
sed -i -e 's,hasLastOrderWithinDays = 30,hasLastOrderWithinDays = -1,' /srv/epages/eproot/Shared/Config/shopmigration.conf
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/deleteObject.pl -storename Store -path /Shops/$ALIAS/PriceLists/RegularCustomer_EUR
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/deleteObject.pl -storename Store -path /Shops/$ALIAS/PriceLists/RegularCustomer_GBP
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/Object/Scripts/set.pl -storename Store -path /Shops/$ALIAS/ ProductLowOnStockAction=2
}
```

* run the report Script to set flag and/or check if everything is in migratable state
```
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration/Scripts/reportMigratableShops.pl -storename Store -list -setflag
```

* alternatively flag the shop for migration manually
```
$PERL $EPAGES_CARTRIDGES/DE_EPAGES/Object/Scripts/set.pl -storename Store -path /Shops/$ALIAS IsMigrationShop=1
```

## Create prepshop
* Variant A: create prep shop with the old script 
```
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration/Scripts/exportShopJson.pl -storename Store \
     -shop $ALIAS -directory $EPAGES_PATCHES/shopexport && \
  $PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration/Scripts/createPrepShop.pl -storename Store \
    -shop $ALIAS -directory $EPAGES_PATCHES/shopexport
```

* Variant B: create prep shop with the new script 
```
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration/Scripts/migrateShops.pl -storename Store -prep -output
```

## Data changes / First Step list im prepShop
* Use the link in Base shop MBO to access the prep shop
* Follow the first step list in prep shop MBO (if available)

## Transfer prep shop into Now shop
* Variant A : transfer prepshop data to the final shop with the old script
```
$PERL $EPAGES_CARTRIDGES/DE_EPAGES/ShopMigration/Scripts/transferPrepShop.pl -storename Store -shop $ALIAS -directory $EPAGES_PATCHES/shopexport
```

* Variant B : transfer prepshop data to the final shop with the new script
```
$PERL /srv/epages/eproot/Cartridges/DE_EPAGES/ShopMigration/Scripts/migrateShops.pl -storename Store -final -output
```

## Compare data
* Compare the data you changed in the prep shop with the data in the Now shop
* Access to the Prep shop MBO (as log as shop is not deleted):
```
PrepShopAdminURL=$($PERL Object/Scripts/get.pl -storename Store -path /PrepShops/$PREPSHOPALIAS WebServerScriptAdminUrlSSL| grep WebServerScriptAdminUrlSSL | cut -d"=" -f2)
echo $PrepShopAdminURL
```
