#========================================================================================
# package      DE_EPAGES::ShopMigration::Hooks::Servlet
# state        public
# description  handles prepshop no login form
#========================================================================================
package DE_EPAGES::ShopMigration::Hooks::Servlet;
use base qw( Exporter );

use strict;
use DE_EPAGES::Core::API::Log qw (GetLog);

#========================================================================================
# function     OnBeforeHandlePermissionDenied
#----------------------------------------------------------------------------------------
# syntax       OnBeforeHandlePermissionDenied( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook UI_BeforeHandlePermissionDenied
#               Check if it is a prepshop and no user is logged in
#               if so, set new loginviewaction to UnityViewPrepShopLogin
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnBeforeHandlePermissionDenied {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    #return if user is logged in
    my $User = $Servlet->user;
    return if defined $User;

    return unless ($Servlet->_isAdministrativRequest ); ##no critic(ProhibitPrivateSubroutineUse)
    return if $Servlet->_isDiagnosticsRequest;          ##no critic(ProhibitPrivateSubroutineUse)

    my $Object = $Servlet->object;
    return unless defined $Object;

    my $Site = $Object->getSite();
    return unless $Site->instanceOf('Shop');
    # only do this for prep shops
    return unless $Site->get('IsMigrationPrepShop');
    #set new loginviewaction -> this is without form
    GetLog->debug('set loginviewaction UnityViewPrepShopLogin.');
    $hParams->{'LoginViewAction'} = 'UnityViewPrepShopLogin';
    return;
}

1;
