#========================================================================================
# package      DE_EPAGES::ShopMigration::Hooks::Session
# state        public
# description  Prevent manual merchant login to PrepShop.
#========================================================================================
package DE_EPAGES::ShopMigration::Hooks::Session;

use strict;
use DE_EPAGES::Core::API::Log       qw (GetLog);
use DE_EPAGES::ShopMigration::API::Constants qw (PREPSHOPS_FOLDER_ALIAS);

#========================================================================================
# function     OnAfterLoginUser
#----------------------------------------------------------------------------------------
# syntax       OnAfterLoginUser( $hParams );
#----------------------------------------------------------------------------------------
# description  Avoids direct logins to prepshops, except internaltestshops
#               (Hook UI_AfterLoginUser)
#----------------------------------------------------------------------------------------
# input        $hParams | <ul>
#                           <li> Servlet - servlet - object </li>
#                          </ul> | ref.hash
#========================================================================================
sub OnAfterLoginUser {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Servlet'};

    # deny login for shop admins on prepshops except for internal test shops
    my $Shop = $Servlet->object->getSite();
    return unless($Shop->instanceOf('Shop')); # may be the root object

    #only prep shops are forbidden
    return unless($Shop->parent->alias eq PREPSHOPS_FOLDER_ALIAS);

    return if ($Shop->get('IsInternalTestShop'));

    my $User = $Servlet->user;
    return unless($User->get('IsMerchant'));

    GetLog->debug('Merchant ' . $User->pathString . ' tried to login manually.');
    $Servlet->logout;
}

1;
