use strict;
use Getopt::Long;
use Time::HiRes qw(time);
use DE_EPAGES::Core::API::Script qw(RunScript);
use DE_EPAGES::Core::API::TestParameter qw(TestString);
use DE_EPAGES::Database::API::Connection qw(RunOnStore);
use DE_EPAGES::Object::API::Factory qw(LoadRootObject);
use DE_EPAGES::ShopMigration::API::MigrationShop qw(ExportShopDataForMigration);

sub Export {
    my ($ShopAlias, $Directory, $ExportPrepShop) = @_;
    TestString('ShopAlias', $ShopAlias);
    TestString('Directory', $Directory);

    my $Shop = LoadRootObject()->child('Shops')->child($ShopAlias);
    if ($ExportPrepShop) {
        $Shop = $Shop->get('MigrationPrepShop');
    }
    ExportShopDataForMigration($Shop, $Directory);
}

sub Main {

    local $| = 1;
    my ($ShopAlias, $Password, $StoreName, $Directory, $ExportPrepShop, $Help);

    GetOptions(
        'help'        => \$Help,
        'passwd=s'    => \$Password,
        'storename=s' => \$StoreName,
        'shop=s'      => \$ShopAlias,
        'directory=s' => \$Directory,
        'prepshop'    => \$ExportPrepShop
    );
    usage() if $Help;
    unless ($StoreName) {
        print STDERR "Missing parameter -storename\n\n";
        usage();
    }
    unless ($ShopAlias) {
        print STDERR "Missing parameter -shop\n\n";
        usage();
    }
    unless ($Directory) {
        print STDERR "Missing parameter -directory\n\n";
        usage();
    }

    my $time1 = time;
    RunOnStore(
        Store      => $StoreName,
        DBPassword => $Password,
        Sub        => sub {
            Export($ShopAlias, $Directory, $ExportPrepShop);
        },
    );
    my $time2 = time;
    printf "need %.3f seconds\n", $time2 - $time1;
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] flags objects

options:
    -passwd     database user password                        ()
    -shop       shop alias                                    required
    -directory  output directory                              required
    -storename  name of store                                 required
flags:
    -prepshop   exports prepshop of shop
    -help       show the command line options

Example:
    perl $0 -storename Store -shop DemoShop -directory /tmp/shopexport
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main,
);

1;
