use strict;

use Getopt::Long;
use Time::HiRes qw(time);
use DE_EPAGES::Cartridge::API::Table::Cartridge qw(ExistsCartridgeByPackage);
use DE_EPAGES::Core::API::Error qw(ExistsError GetError);
use DE_EPAGES::Core::API::Script qw(RunScript);
use DE_EPAGES::Core::API::Warning qw(Warning);
use DE_EPAGES::Database::API::Connection qw(RunOnStore);
use DE_EPAGES::Object::API::Factory qw(LoadRootObject LoadObject);
use DE_EPAGES::WebInterface::API::MessageCenter qw(SynchronizeCache);
use DE_EPAGES::ShopMigration::API::Constants qw(PREPSHOPS_FOLDER_ALIAS);
use DE_EPAGES::ShopMigration::API::PrepShopLoginToken qw(IsValidToken);

sub Main {

    local $| = 1;

    my $Help;
    my $NoOutput;
    my $Password;
    my $StoreName;

    GetOptions(
        'help'        => \$Help,
        'nooutput'    => \$NoOutput,
        'passwd=s'    => \$Password,
        'storename=s' => \$StoreName,
    );

    usage() unless defined $StoreName;

    my $time1 = time;

    RunOnStore(
        Store      => $StoreName,
        DBPassword => $Password,
        Sub        => sub {
            return unless (ExistsCartridgeByPackage('DE_EPAGES::ShopMigration'));

            my $Store = LoadRootObject();
            my $aShopIDs = $Store->child(PREPSHOPS_FOLDER_ALIAS)->findChildren;
            foreach my $ShopID (@{$aShopIDs}) {
                my $Shop = LoadObject($ShopID);
                foreach my $Merchant (@{$Shop->child('Groups')->child('Merchants')->get('Members')}) {
                    my $TokenFolder = $Merchant->existsChild('PrepShopLoginTokens') ? $Merchant->child('PrepShopLoginTokens') : undef;
                    next unless defined $TokenFolder;
                    foreach my $LoginTokenObject (@{$TokenFolder->children}) {
                        unless (IsValidToken($LoginTokenObject->alias, $TokenFolder)) {
                            $LoginTokenObject->delete;
                        }
                    }
                }
            }
        }
    );

    my $time2 = time;
    my $seconds = $time2 - $time1;
    my $logmsg = sprintf('need %.3f seconds', $seconds);
    print $logmsg . "\n" unless $NoOutput;

    eval {SynchronizeCache();};
    Warning(GetError()) if ExistsError();
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] flags objects

options:
    -passwd     database user password              ()
    -storename  name of store                       ()

flags:
    -help       show the command line options
    -nooutput   do not print any output

Example:
    perl $0 -storename Store

END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main,
);
