#========================================================================================
# package      DE_EPAGES::ShopMigration::t::MigrationShop
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for DE_EPAGES::ShopMigration::API::MigrationShop
#========================================================================================
package  DE_EPAGES::ShopMigration::t::MigrationShop;
use base DE_EPAGES::Test::API::StoreUnitTest;

use strict;
use utf8;
use warnings;
use DE_EPAGES::Object::API::Factory qw( LoadRootObject LoadClassByAlias );
use DE_EPAGES::ShopMigration::API::MigrationShop qw( CreatePrepShop ExistsPrepShop );
use Test::More;

if ($ENV{SKIP_IN_PR_TESTS}) {
    plan skip_all => 'Skipping it because SKIP_IN_PR_TESTS == 1';
} else {
    plan tests => 5;
}

sub test {
    testMigrationShop();
    done_testing();
}

my %TestData = (
    TestShop          => undef,
    TestShopAlias     => 'Test2CreatePrepShop',
);

sub testMigrationShop {
    my $Shop = $TestData{TestShop};
    note('test MigrationShop');
    isnt($Shop, undef, 'epages6 Testshop exists');

    is(ExistsPrepShop($Shop), 0, 'ExistsPrepShop() is false');

    my $PrepShop = CreatePrepShop($Shop);
    isnt($PrepShop, undef, 'PrepShop created');

    is(ExistsPrepShop($Shop), 1, 'ExistsPrepShop() is true');

    my $ShopTypeRef = $PrepShop->get('ShopTypeRef');
    is($ShopTypeRef->alias, 'UnityDE', 'PrepShop mapped to UnityDE shoptype');
}

sub init {
    my $self = shift;

    $self->SUPER::init;
    my $ShopAlias = $TestData{TestShopAlias};
    my $System = LoadRootObject();
    my $Folder = $System->folder('Shops');
    my $Shop;
    my $ShopTypeRefFolder = $System->folder('ShopTypeRefs');
    my $Class = LoadClassByAlias('ShopTypeRef');
    $Class->insertObject({Alias=>'UnityDE', 'Parent'=>$ShopTypeRefFolder}) unless ($ShopTypeRefFolder->existsChild('UnityDE'));
    $Class->insertObject({Alias=>'ECom5000', 'Parent'=>$ShopTypeRefFolder}) unless ($ShopTypeRefFolder->existsChild('ECom5000'));
    if ($Folder->existsChild($ShopAlias)) {
        $Shop = $Folder->child($ShopAlias);
    } else {
        $Shop = $Folder->insertChild('Shop', {
            Alias => $ShopAlias,
            ShopTypeRef => $ShopTypeRefFolder->child('ECom5000'),
            WebServerScriptNamePart => $ShopAlias
        });
    }
    $TestData{TestShop} = $Shop;
    return;
}

sub cleanup {
    my $self = shift;

    my $System = LoadRootObject();
    my $Folder = $System->folder('Shops');
    my $TestShopAlias = $TestData{TestShopAlias};
    if ($Folder->existsChild($TestShopAlias)) {
        my $Shop =$Folder->child($TestShopAlias);
        my $PrepShop = $Shop->get('MigrationPrepShop');
        $Shop->delete();
        $PrepShop->delete() if defined $PrepShop;
    }
    $self->SUPER::cleanup;
    return;
}

__PACKAGE__->runScript();

1;
