#========================================================================================
# package      DE_EPAGES::Spreedly::API::GatewayController
# state        private
#----------------------------------------------------------------------------------------
# description  Controller for managing Spreedly gateways
#========================================================================================
package DE_EPAGES::Spreedly::API::GatewayController;

use DE_EPAGES::Core::API::TestParameter qw ( TestObject );
use DE_EPAGES::Spreedly::API::RestClient;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Spreedly::API::GatewayController->new( $Servlet );
#----------------------------------------------------------------------------------------
# description  instantiate controller to manage gateway tasks.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
# return       $GatewayController | gateway controller | DE_EPAGES::Spreedly::API::GatewayController
#========================================================================================
sub new {
    my $class = shift;
    my ($Servlet) = @_;

    TestObject('Servlet', $Servlet, 'DE_EPAGES::Presentation::Servlet::Permission');

    my $self = bless {}, $class;
    $self->{'servlet'} = $Servlet;

    return $self;
}

#========================================================================================
# function     saveCredentials
# state        public
#----------------------------------------------------------------------------------------
# syntax       $haveCredentialsChanged = $self->saveCredentials();
#----------------------------------------------------------------------------------------
# description  Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $hAdditionalBodyParams | hash with gateway controller parameters | ref.hash
# return       $Response | epagesj gateway endpoint object | object
#========================================================================================
sub saveCredentials {
    my $self = shift;
    my ($hAdditionalBodyParams) = @_;

    my $Servlet = $self->{'servlet'};
    my $Shop = $Servlet->object()->getSite();
    my $PaymentMethod = $Servlet->object();
    my $PaymentType = $PaymentMethod->get('PaymentType');

    my $RestClient = DE_EPAGES::Spreedly::API::RestClient->create({Shop => $Shop});

    return $RestClient->createResource($PaymentType->get('GatewayName'), $hAdditionalBodyParams);
}

#========================================================================================
# function     getToken
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hGatewayEntity = $self->getToken($Shop, $GatewayName);
#----------------------------------------------------------------------------------------
# description  Controller to get gateway token from epagesj.
#----------------------------------------------------------------------------------------
# input        $Shop | shop object | object
# input        $GatewayName | gateway name | string
# return       $hGatewayEntity | gateway entity hash with token | hash ref.
#========================================================================================
sub getToken {
    my $self = shift;
    my ($Shop, $GatewayName) = @_;

    my $RestClient = DE_EPAGES::Spreedly::API::RestClient->create({Shop => $Shop});

    return $RestClient->getResource($GatewayName);
}

1;
