#==============================================================================
# package      DE_EPAGES::Spreedly::Hooks::Attribute
# state        private
#==============================================================================
package DE_EPAGES::Spreedly::Hooks::Attribute;

use DE_EPAGES::Object::API::Factory qw ( JoinObjectPath LoadObjectByPath );
use DE_EPAGES::Spreedly::API::Constants qw ( @PAYMENT_TYPE_NAMES );
use DE_EPAGES::ThirdPartyConfig::API::Constants qw ( ATTRIBUTES_CATEGORY_PAYMENT );

use strict;

#========================================================================================
# function     OnGetThirdPartyConfigAttributes
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetThirdPartyConfigAttributes($hParams);
#----------------------------------------------------------------------------------------
# description  API_GetThirdPartyConfigAttributes triggered, register attributes to be
#               configured in PBO
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>AttributesCategory
#                   <li>LanguageID
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetThirdPartyConfigAttributes {
    my ($hParams) = @_;

    return unless $hParams->{'AttributesCategory'} eq ATTRIBUTES_CATEGORY_PAYMENT;

    for my $PaymentTypeName (@PAYMENT_TYPE_NAMES) {
        my $aAttribute = _BuildAttributes($PaymentTypeName);
        push(
            @{ $hParams->{'Attributes'} },
            {
                'SectionID'   => $PaymentTypeName,
                'SectionName' => $PaymentTypeName,
                'Attributes'  => $aAttribute,
            }
        );
    }

    return;
}

#----------------------------------------------------------------------------------------
sub _BuildAttributes {
    my ($PaymentTypeName) = @_;

    my @Attributes;
    my $PaymentType = LoadObjectByPath( JoinObjectPath( [ 'PaymentTypes', $PaymentTypeName ] ) );
    my $PaymentTypeObjectID = $PaymentType->id();

    push(@Attributes, {
        'ObjectID'       => $PaymentTypeObjectID,
        'AttributeAlias' => 'Logging',
        'NamePrefix'     => $PaymentTypeName,
    });

    if($PaymentTypeName ~~ [qw( SpreedlyStripe SpreedlyStripePaymentIntents )]){
        push(@Attributes, {
            'ObjectID'       => $PaymentTypeObjectID,
            'AttributeAlias' => 'OnBoardingUrl',
            'NamePrefix'     => $PaymentTypeName,
        });
    }

    return \@Attributes;
}

1;
