#========================================================================================
# package      DE_EPAGES::Spreedly::t::unit::UI_PaymentMethodSpreedlyStripePaymentIntents
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for UI::Provider
#========================================================================================
package DE_EPAGES::Spreedly::t::unit::UI_PaymentMethodSpreedlyStripePaymentIntents;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::Mockify qw ( GetParametersFromMockifyCall WasCalled );
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Exception;
use Test::MockObject::Extends;
use Test::More;

use strict;

use constant GATEWAY_CREATION_RESPONSE => {
      'gatewayId' => 'stripe_payment_intents',
      'shopGuid' => 'shop_guid',
      'stripeAccessToken' => 'stripe_access_token',
      'stripeAccountId' => 'stripe_account_id',
      'stripeRefreshToken' => 'stripe_refresh_token',
      'token' => 'spreedly_token'
};


sub test {
    my $self = shift;

    $self->test_ViewSettingsSpreedlyStripePaymentIntents_View_General();
    $self->test_ViewSettingsSpreedlyStripePaymentIntents_Backlink_With_AuthorizationCode();
    $self->test_ViewSettingsSpreedlyStripePaymentIntents_Backlink_With_Error();
    $self->test_LogPayment_FunctionPointer();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_ViewSettingsSpreedlyStripePaymentIntents_View_General {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $hQueryValues = {};
    my $Servlet = $self->_createServlet($hQueryValues);

    my $hSUTVars = {
        'Servlet' => $Servlet,
        'QueryValues' => $hQueryValues
    };

    my $SUT = $self->_createSUT($hSUTVars);

    my $Result = $SUT->ViewSettingsSpreedlyStripePaymentIntents();

    #Check Return Data is Servlet
    isa_ok($Result, 'DE_EPAGES::Presentation::Servlet::Permission', "$SubTestName - verify return of ViewSettingsSpreedlyStripePaymentIntents");

    #Check Servlet vars
    is(
        $Servlet->vars('ConnectAndReconnectUrl'),
        'https://ConnectAndReconnect.url',
        "$SubTestName - verify servlet var ConnectAndReconnectUrl was set accordingly."
    );

    #Check _LogPayment and _createGateway are not called
    ok(!WasCalled( $SUT, '_LogPayment' ), "$SubTestName - _LogPayment was not called.");
    ok(!WasCalled( $SUT, '_createGateway' ), "$SubTestName - _createGateway was not called.");
}
#----------------------------------------------------------------------------------------
sub test_ViewSettingsSpreedlyStripePaymentIntents_Backlink_With_AuthorizationCode {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $AuthCode = 'ac_8NPktx3GXN4UBeZGsTEBXPZsv5koO0h5';

    my $hQueryValues = {
        'code' => $AuthCode,
    };
    my $Servlet = $self->_createServlet($hQueryValues);

    my $hSUTVars = {
        'Servlet' => $Servlet,
        'QueryValues' => $hQueryValues,
        'AuthCode' => $AuthCode,
    };

    my $SUT = $self->_createSUT($hSUTVars);

    my $Result = $SUT->ViewSettingsSpreedlyStripePaymentIntents();

    #Check Return Data is Servlet
    isa_ok($Result, 'DE_EPAGES::Presentation::Servlet::Permission', "$SubTestName - verify return of ViewSettingsSpreedlyStripePaymentIntents");

    #Check Servlet vars
    is(
        $Servlet->vars('ConnectAndReconnectUrl'),
        'https://ConnectAndReconnect.url',
        "$SubTestName - verify servlet var ConnectAndReconnectUrl was set accordingly."
    );
    is($Servlet->vars('HasSpreedlyConnectionError'), undef , "$SubTestName - verify servlet var HasSpreedlyConnectionError was not set.");

    #Check _LogPayment is called
    ok(WasCalled($SUT, '_LogPayment'), "$SubTestName - _LogPayment was called.");

    #Check _createGateway is called with right Parameters
    my $aCreateGatewayParams = GetParametersFromMockifyCall($SUT, '_createGateway');
    is($aCreateGatewayParams->[0], 'ac_8NPktx3GXN4UBeZGsTEBXPZsv5koO0h5', "$SubTestName - checks if AuthorizationCode is sent.");
    is($aCreateGatewayParams->[1], '1', "$SubTestName - checks if IsInternalTestShop is sent accordingly.");

    is($SUT->{'PaymentMethod'}->get('StripeAccessToken'), 'stripe_access_token', "$SubTestName - StripeAccessToken has been saved");
    is($SUT->{'PaymentMethod'}->get('StripeAccountId'), 'stripe_account_id', "$SubTestName - StripeAccountId has been saved");
    is($SUT->{'PaymentMethod'}->get('StripeRefreshToken'), 'stripe_refresh_token', "$SubTestName - StripeRefreshToken has been saved");
}
#----------------------------------------------------------------------------------------
sub test_ViewSettingsSpreedlyStripePaymentIntents_Backlink_With_Error {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $hQueryValues = {
        'error' => 'access_denied',
    };
    my $Servlet = $self->_createServlet($hQueryValues);

    my $hSUTVars = {
        'Servlet' => $Servlet,
        'QueryValues' => $hQueryValues
    };

    my $SUT = $self->_createSUT($hSUTVars);

    my $Result = $SUT->ViewSettingsSpreedlyStripePaymentIntents();

    #Check Return Data is Servlet
    isa_ok($Result, 'DE_EPAGES::Presentation::Servlet::Permission', "$SubTestName - verify return of ViewSettingsSpreedlyStripePaymentIntents");

    #Check Servlet vars
    is(
        $Servlet->vars('ConnectAndReconnectUrl'),
        'https://ConnectAndReconnect.url',
        "$SubTestName - verify servlet var ConnectAndReconnectUrl was set accordingly."
    );
    is($Servlet->vars('HasSpreedlyConnectionError'), '1', "$SubTestName - verify servlet var HasSpreedlyConnectionError was set accordingly.");

    #Check _LogPayment is called but _createGateway is not called
    ok(WasCalled($SUT, '_LogPayment'), "$SubTestName - _LogPayment was called.");
    ok(!WasCalled($SUT, '_createGateway'), "$SubTestName - _createGateway was not called.");
}
#----------------------------------------------------------------------------------------
sub test_LogPayment_FunctionPointer {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $AuthCode = 'ac_8NPktx3GXN4UBeZGsTEBXPZsv5koO0h5';

    my $hQueryValues = {
        'code' => $AuthCode,
    };
    my $Servlet = $self->_createServlet($hQueryValues);

    my $hSUTVars = {
        'Servlet' => $Servlet,
        'QueryValues' => $hQueryValues,
        'AuthCode' => $AuthCode,
    };

    my $SUT = $self->_createSUT($hSUTVars);

    $SUT->ViewSettingsSpreedlyStripePaymentIntents();

    my $aLogPaymentParams = GetParametersFromMockifyCall($SUT, '_LogPayment');

    my $TestMatchingString = "{'code' => ['$AuthCode']}";
    my $LogPaymentFunctionPointer = $aLogPaymentParams->[4];

    $LogPaymentFunctionPointer->(\$TestMatchingString);

    is($TestMatchingString, '{\'code\' => [\'ac_---replaced---\']}',"$SubTestName - check if Matched String is replaced by replacer.");
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hVars) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyStripePaymentIntents',
        [ $hVars->{'Servlet'}, $self->_createPaymentMethod($hVars) ]);

    $Mockify->addMockWithReturnValueAndParameterCheck( '_createGateway', GATEWAY_CREATION_RESPONSE,
        [
           {'string' => $hVars->{'AuthCode'} },
           {'string' => '1'}
        ]);
    $Mockify->addMockWithReturnValue('_getCurrentURL', 'www.currentURL.com');
    $Mockify->addMockWithReturnValueAndParameterCheck('_LogPayment', undef ,
        [ {'string' => 'SpreedlyStripePaymentIntents'},
          {'string' => 'Redirected from changeAction BacklinkStripeOnboarding. Return data from StripePaymentIntents'},
          {'hashref' => $hVars->{'QueryValues'}},
          'undef',
          'sub'
    ]);
    $Mockify->mock('_createStripeUrlBuilder',$self->_createStripeUrlBuilder());

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createStripeUrlBuilder {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::Spreedly::API::StripeUrlBuilder',
                   $aParameterList
              );

    $Mockify->mock(
        'buildConnectAndReconnectUrl',
        'https://ConnectAndReconnect.url',
        [
            {'object' => 'DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyStripePaymentIntents'},
            {'string' => 'www.currentURL.com'}
        ]
    );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createForm {
    my $self = shift;
    my ($hParams) = @_;
    my $MockifyForm = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Presentation::API::Form');

    $MockifyForm->addMockWithConditionalReturn('queryValue', $hParams->{'code'}, [ {'string' => 'code' } ]);
    $MockifyForm->addMockWithConditionalReturn('queryValue', $hParams->{'error'}, [ {'string' => 'error' } ]);
    $MockifyForm->addMockWithReturnValue('queryValues', $hParams);

    return $MockifyForm->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my $hAttribute = {
        'IsInternalTestShop' => '1'
    };
    my $MockedShop = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', $hAttribute);

    return $MockedShop->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createServlet {
    my $self = shift;
    my ($Params) = @_;

    my $MockifyProvider = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::ShopConfiguration::API::Object::Provider', {});
    my $Provider = $MockifyProvider->getMockObject();
    my $MockifyServlet = DE_EPAGES::Test::Mock::MockifyServlet->new($Provider);

    $MockifyServlet->addMockWithReturnValue('form', $self->_createForm($Params));

    return $MockifyServlet->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentMethod {
    my $self = shift;
    my ($hVars) = @_;
    my $hAttributes = {
        'Site' => $self->_createShop($hVars),
        'PaymentType' => $self->_createPaymentType()
    };

    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Spreedly::API::Object::PaymentMethodSpreedlyStripePaymentIntents', $hAttributes
    );

    return $MockifyPaymentMethod->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentType {
     my $self = shift;
     my $hAttributes = {
        'Alias' => 'SpreedlyStripePaymentIntents',
        'TestAccountName' => 'TestName',
        'LiveAccountName' => 'LiveName'
    };

    my $MockifyPaymentType = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Spreedly::API::Object::PaymentTypeSpreedly', $hAttributes);
    return $MockifyPaymentType->getMockObject();
}

__PACKAGE__->runScript();
